#!/usr/local/sbin/charm-env python3
"""Sudo Pair actions."""
#
# Copyright 2016,2019,2020 Canonical Ltd
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import os
import sys

from charmhelpers.core.hookenv import action_fail, action_set, status_set


sys.path.append("lib")

import libsudopair  # NOQA


def remove():
    """Remove sudo-pair config and binaries."""
    sph = libsudopair.SudoPairHelper()
    sph.deconfigure()
    msg = "Successfully removed sudo-pair config and binaries"
    action_set({"message": msg})
    status_set("active", msg)


# A dictionary of all the defined actions to callables (which take
# parsed arguments).
ACTIONS = {"remove-sudopair": remove}


def main(args):
    """Dispatch actions based on command arguments."""
    action_name = os.path.basename(args[0])
    try:
        ACTIONS[action_name]()
    except Exception as e:
        action_fail(str(e))


if __name__ == "__main__":
    sys.exit(main(sys.argv))
