"""Charm reactive hooks."""

from charmhelpers.core import hookenv

from charms.reactive import hook, remove_state, set_state, when, when_not

from libsudopair import SudoPairHelper

sph = SudoPairHelper()


@when("apt.installed.socat")
@when_not("sudo-pair.configured")
def install_sudo_pair():
    """Install sudo pair.

    Install sudo_pair.so, create socket dir, copy sudo_approve to /usr/bin
    and copy prompts to /etc.
    """
    sph.install_sudo_pair_so()

    sph.create_socket_dir()

    sph.create_tmpfiles_conf()

    sph.copy_user_prompt()

    sph.copy_pair_prompt()

    sph.render_sudo_approve()

    # Add "Defaults log_output to /etc/sudoers
    sph.copy_sudoers()

    # If there are cmds to bypass sudo pairing create file unders sudoers.d
    sph.render_bypass_cmds()

    # Add Plugin sudo_pair sudo_pair.so to sudo.conf
    sph.render_sudo_conf()

    set_state("sudo-pair.installed")
    set_state("sudo-pair.configured")
    hookenv.status_set(
        "active",
        "sudo pairing for users groups: [{}]".format(sph.get_config()["gids_enforced"]),
    )


@hook("config-changed")
def reconfigure_sudo_pair_charm():
    """Run config-changed hook."""
    sph.set_charm_config(hookenv.config())
    remove_state("sudo-pair.configured")


@hook("stop")
def stop():
    """Run stop hook and remove charm configuration."""
    sph.deconfigure()
    remove_state("sudo-pair.installed")
