#!/usr/bin/python3
"""Unit tests utilities."""

import grp
import os
import pwd
from pathlib import Path

import pytest


@pytest.fixture
def mock_hookenv_config(monkeypatch):
    """Mock hookenv config."""
    import yaml

    def mock_config():
        cfg = {}
        yml = yaml.load(open("./config.yaml"))

        # Load all defaults
        for key, value in yml["options"].items():
            cfg[key] = value["default"]

        return cfg

    monkeypatch.setattr("charmhelpers.core.hookenv.config", mock_config)


@pytest.fixture
def mock_charm_dir(monkeypatch):
    """Mock charm dir."""
    monkeypatch.setattr("charmhelpers.core.hookenv.charm_dir", lambda: ".")


@pytest.fixture
def sph(mock_hookenv_config, mock_charm_dir, tmpdir):
    """Return SudoPairHelpers with mocks."""
    from libsudopair import SudoPairHelper

    sph = SudoPairHelper()
    sph.owner = pwd.getpwuid(os.getuid()).pw_name
    sph.group = grp.getgrgid(os.getgid()).gr_name
    sph.sudo_conf_path = tmpdir.join(sph.sudo_conf_path)
    sph.socket_dir = tmpdir.join(sph.socket_dir)
    td = Path(tmpdir.join(sph.tmpfiles_conf).strpath).parent
    td.mkdir(parents=True, exist_ok=True, mode=0o755)
    sph.tmpfiles_conf = tmpdir.join(sph.tmpfiles_conf)
    sph.sudo_lib_path = tmpdir.join(sph.sudo_lib_path)
    sph.user_prompt_path = tmpdir.join(sph.user_prompt_path)
    sph.pair_prompt_path = tmpdir.join(sph.pair_prompt_path)
    sph.sudoers_path = tmpdir.join(sph.sudoers_path)
    sph.binary_path = tmpdir.join(sph.binary_path)
    sph.sudoers_bypass_path = tmpdir.join(sph.sudoers_bypass_path)
    sph.socket_dir_perms = 0o775
    sph.sudo_conf_perms = 0o644
    return sph
